/**
 * GMyth Library
 * 
 * @file gmyth/gmyth_common.h
 * 
 * @brief <p> This file contains basic common functions for the gmyth library.
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Leonardo Sobral Cunha <leonardo.cunha@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef GMYTH_COMMON_H_
#define GMYTH_COMMON_H_

#include <glib.h>
#include <time.h>

G_BEGIN_DECLS

/**
 * The GMythChannelInfo structure represents the channel information
 * stored in the backend database.
 */
typedef struct {
	/** The channel ID in backend database */
	int channel_ID;
	
	/** The channel name in backend database */
	GString *channel_name;

} GMythChannelInfo;


/**
 * The GMythProgramInfo structure represents a program information
 * stored in the database. It could be a program from the EPG data,
 * a program scheduled to be recorded, or a program already recorded.
 */
typedef struct {
	
	/** The channel unique ID. */
    GString *chanid;
    
    /** The program start time. */
    time_t startts;
    /** The program end time. */
    time_t endts;
    /** The recording schedule start time. */
    time_t recstartts;
    /** The recording schedule end time */
    time_t recendts;
    
    /** The program title. */
    GString *title;
    /** The program subtitle. */
    GString *subtitle;
    /** The program description. */
    GString *description;
    /** The program category. */
    GString *category;
    
    GString *chanstr;
    GString *chansign;
    /** The associated channel name. */
    GString *channame;
    int chancommfree;
    GString *chanOutputFilters;
    
    GString *seriesid;
    /** The program unique id. */
    GString *programid;
    GString * catType;

    GString * sortTitle;  

	/** A flag informing if the program has video or not. */    
    gboolean isVideo;
    int lenMins;
    
    GString *year;    
    double stars;
    int repeat;
    
    time_t originalAirDate;
    time_t lastmodified;
    time_t lastInUseTime;
    
    gboolean hasAirDate;

    int spread;
    int startCol;

//    enum RecStatusType recstatus;
//    enum RecStatusType oldrecstatus;
//    enum RecStatusType savedrecstatus;
    int recpriority2;
    int reactivate;    

    int recordid;
    int parentid;   
    //enum RecordingType rectype;
    //enum RecordingDupInType dupin;
    //enum RecordingDupMethodType dupmethod;
    
    /** The backend video source id associated to this program.*/
    int sourceid;
    /** the backend input id associated to this program.*/
    int inputid;
    /** The backend card id associated to this program.*/
    int cardid;
    gboolean shareable;
    gboolean duplicate;
  
    GString * schedulerid;
    int findid;

    int programflags;
    int transcoder;

    //proginfo->spread = -1;
    //proginfo->programflags = proginfo->getProgramFlags();

    GString *recgroup;
    GString *playgroup;
    int recpriority;

	/** The file size of the recorded program.*/
    long long filesize;
    /** The file name of the recorded program.*/
    GString *pathname;
    GString *hostname;
        
    /* AvailableStatusType availableStatus;*/
 
} GMythProgramInfo;


void gmyth_free_channel_list(GList *list);
void gmyth_free_program_list(GList *list);

void gmyth_channel_info_print(GMythChannelInfo *channel_info);
void gmyth_program_info_print(GMythProgramInfo *program_info);

G_END_DECLS

#endif /* GMYTH_COMMON_H_ */
